pub struct JITEngine { /* private fields */ }Expand description
A WebAssembly JIT Engine.
Implementations
Sourceimpl JITEngine
impl JITEngine
Sourcepub fn headless() -> Self
pub fn headless() -> Self
Create a headless JITEngine
A headless engine is an engine without any compiler attached. This is useful for assuring a minimal runtime for running WebAssembly modules.
For example, for running in IoT devices where compilers are very expensive, or also to optimize startup speed.
Important
Headless engines can’t compile or validate any modules,
they just take already processed Modules (via Module::serialize).